% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/crcal.R
\name{crystSG}
\alias{crystSG}
\title{Relative Crystallinity Calculation of X-Ray Diffraction Pattern of Starch by Frost Method}
\usage{
crystSG(pattern, N = 101, iter = 400, p = 2)
}
\arguments{
\item{pattern}{matrix. The matrix of X-ray diffraction pattern.  The first row corresponds to Bragg angle 2\eqn{\theta}; the second row corresponds to intensity.}

\item{N}{numeric. N length of the smoothing window (number of variables). Defaults to 101.}

\item{iter}{numeric. Iter number of iterations. Defaults to 400.}

\item{p}{numeric. Filter order. Defaults to 2.}
}
\value{
An object of class crystSG, which is a list with the following components:
  \item{original}{Original matrix of X-ray diffraction patterns.}
  \item{background}{Estimation of the background shape (curve of the amorphous starch).}
  \item{corrected}{Estimation of residual crystalline area (curve of the crystalline starch).}
  \item{summary}{Summary calculation of crystallinity. Total area under the curve of the diffraction pattern (A.U.); Amorphous area (A.U.); Crystalline area (A.U.); Relative crystallinity (\%).}
}
\description{
Allow  to calculate the relative crystallinity of starch by XRD.
The basic concept of Frost approach involves obtaining a smoothed
line that separates the amorphous and crystalline starch of an X-ray
diffraction pattern. This smoothed line is achieved by applying
a Savitzky-Golay smoothing method to the original pattern.
}
\details{
Calculate the relative starch crystallinity of XRD pattern by Frost method.
}
\examples{
data(XRD)
# Convert data frame to matrix, select A-type starch
pattern <- as.matrix(t(XRD[, c("Bragg_angle","A")]))
# List of crystallinity components
crs <- crystSG(pattern, N = 101, iter = 400, p = 2)
# Original matrix
original <- crs$original
# Background shape
background <- crs$background
# Curve of the crystalline starch
corrected <- crs$corrected
# Summary calculation of crystallinity
summary <- crs$summary
}
\author{
Claudio Pozo Valenzuela [aut, cre] and Saddys Rodriguez-llamazares [aut]
}
\references{
Frost, K., et al. (2009). "Crystallinity and structure of starch using wide angle X-ray scattering." Carbohydrate Polymers 78(3): 543-548.
}

